diff --git a/Form1.resx b/Form1.resx
index 1af7de1..4f24d55 100644
--- a/Form1.resx
+++ b/Form1.resx
@@ -1,120 +1,120 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- text/microsoft-resx
-
-
- 2.0
-
-
- System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
- System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
\ No newline at end of file
diff --git a/Form1.Designer.cs b/Form1.Designer.cs
index 93d5a84..4c74e7b 100644
--- a/Form1.Designer.cs
+++ b/Form1.Designer.cs
@@ -1,39 +1,96 @@
-namespace GuessTheCard
-{
- partial class Form1
- {
- ///
- /// Required designer variable.
- ///
- private System.ComponentModel.IContainer components = null;
-
- ///
- /// Clean up any resources being used.
- ///
- /// true if managed resources should be disposed; otherwise, false.
- protected override void Dispose(bool disposing)
- {
- if (disposing && (components != null))
- {
- components.Dispose();
- }
- base.Dispose(disposing);
- }
-
- #region Windows Form Designer generated code
-
- ///
- /// Required method for Designer support - do not modify
- /// the contents of this method with the code editor.
- ///
- private void InitializeComponent()
- {
- components = new System.ComponentModel.Container();
- AutoScaleMode = AutoScaleMode.Font;
- ClientSize = new Size(800, 450);
- Text = "Form1";
- }
-
- #endregion
- }
-}
+namespace GuessTheCard
+{
+ partial class Form1
+ {
+ ///
+ /// Required designer variable.
+ ///
+ private System.ComponentModel.IContainer components = null;
+
+ ///
+ /// Clean up any resources being used.
+ ///
+ /// true if managed resources should be disposed; otherwise, false.
+ protected override void Dispose(bool disposing)
+ {
+ if (disposing && (components != null))
+ {
+ components.Dispose();
+ }
+ base.Dispose(disposing);
+ }
+
+ #region Windows Form Designer generated code
+
+ ///
+ /// Required method for Designer support - do not modify
+ /// the contents of this method with the code editor.
+ ///
+ private void InitializeComponent()
+ {
+ LabelCard = new Label();
+ labelScore = new Label();
+ buttonHigh = new Button();
+ buttonLow = new Button();
+ SuspendLayout();
+ //
+ // LabelCard
+ //
+ LabelCard.AutoSize = true;
+ LabelCard.Font = new Font("Segoe UI", 32F);
+ LabelCard.Location = new Point(12, 58);
+ LabelCard.Name = "LabelCard";
+ LabelCard.Size = new Size(240, 59);
+ LabelCard.TabIndex = 0;
+ LabelCard.Text = "Card Result";
+ //
+ // labelScore
+ //
+ labelScore.AutoSize = true;
+ labelScore.Location = new Point(12, 9);
+ labelScore.Name = "labelScore";
+ labelScore.Size = new Size(36, 15);
+ labelScore.TabIndex = 1;
+ labelScore.Text = "Score";
+ //
+ // buttonHigh
+ //
+ buttonHigh.Location = new Point(313, 12);
+ buttonHigh.Name = "buttonHigh";
+ buttonHigh.Size = new Size(75, 23);
+ buttonHigh.TabIndex = 2;
+ buttonHigh.Text = "Higher";
+ buttonHigh.UseVisualStyleBackColor = true;
+ //
+ // buttonLow
+ //
+ buttonLow.Location = new Point(313, 41);
+ buttonLow.Name = "buttonLow";
+ buttonLow.Size = new Size(75, 23);
+ buttonLow.TabIndex = 3;
+ buttonLow.Text = "Lower";
+ buttonLow.UseVisualStyleBackColor = true;
+ //
+ // Form1
+ //
+ AutoScaleDimensions = new SizeF(7F, 15F);
+ AutoScaleMode = AutoScaleMode.Font;
+ ClientSize = new Size(400, 155);
+ Controls.Add(buttonLow);
+ Controls.Add(buttonHigh);
+ Controls.Add(labelScore);
+ Controls.Add(LabelCard);
+ Name = "Form1";
+ Text = "Form1";
+ ResumeLayout(false);
+ PerformLayout();
+ }
+
+ #endregion
+
+ private Label LabelCard;
+ private Label labelScore;
+ private Button buttonHigh;
+ private Button buttonLow;
+ }
+}